#version 110

#ifdef GL_ES
precision mediump float;
#endif

uniform vec3      iResolution;           // viewport resolution (in pixels)
uniform float     iDuration;             // shader playback total time (in seconds)
uniform float     iTime;                 // shader playback current time (in seconds)
uniform float     iTimeDelta;            // render time (in seconds)
uniform int       iFrame;                // shader playback frame
uniform float     iChannelTime[8];       // channel playback time (in seconds)
uniform vec3      iChannelResolution[8]; // channel resolution (in pixels)
uniform vec4      iMouse;                // mouse pixel coords. xy: current (if MLB down), zw: click
uniform sampler2D iChannel[8];           // input channel. XX = 2D/Cube
uniform vec4      iDate;                 // (year, month, day, time in seconds)
uniform float     iSampleRate;           // sound sample rate (i.e., 44100)

uniform float     strength;


float iProgress = iTime / iDuration;

const float PI = 3.141592653589793;

////////////////////////////////////////////////////////////////////////////////////////////////////////////

// Custom parameters
float size = 0.04;
float zoom = 30.0;
float colorSeparation = 0.3;
 
void mainImage( out vec4 fragColor, in vec2 fragCoord ) {
  vec2 p = fragCoord / iResolution.xy;
  float inv = 1. - iProgress;
  vec2 disp = size*vec2(cos(zoom*p.x), sin(zoom*p.y));
  vec4 texTo = texture2D(iChannel[1], p + inv*disp);
  vec4 texFrom = vec4(
    texture2D(iChannel[0], p + iProgress*disp*(1.0 - colorSeparation)).r,
    texture2D(iChannel[0], p + iProgress*disp).g,
    texture2D(iChannel[0], p + iProgress*disp*(1.0 + colorSeparation)).b,
    1.0);
  fragColor = texTo*iProgress + texFrom*inv;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////

void main() {
    mainImage(gl_FragColor, gl_FragCoord.xy);
}
